% figure2a.m  Generate panels of Figure 2a in Pritchett and Murray (2015)
%             i.e., experiment 1, proxy decision space and GDD function fit

clear; clc; clf;

% initialize
addpath(fullfile(pwd,'tools'));  % add tool folder to path
assertstats;                     % check for the statistics toolbox

% choose subject (subject = 1, 2, or 3)
subject = 1;
fname = sprintf('data/experiment1_subject%d.txt',subject);
fprintf('processing %s\n',fname);

% load data and select columns
trials = load(fname,'-ascii');
signal = trials(:,3);           % signal order:  1 = white disk first, 2 = black disk first
sigcst = trials(:,6);           % signal contrast
rngseeds = trials(:,[ 4 5 ]);   % random number generator seeds
response = trials(:,7);         % observer response:  1 = judged white disk first, 2 = judged black disk first

% calculate a radially pooled, unit-energy classification image
fprintf('  calculating classification image ...\n');
cimage = calcclass_experiment1( signal, response, rngseeds, subject );

% calculate proxy decision variables
fprintf('  calculating proxy decision variables ...\n');
[ dvar1, dvar2 ] = calcdvar_experiment1( signal, sigcst, rngseeds, cimage );

% calculate proxy decision space
fprintf('  calculating proxy decision space ...\n');
dspace = calcdspace( dvar1, dvar2, response );

% fit GDD function to proxy decision space
fprintf('  fitting GDD function to proxy decision space ...\n');
param = fitgddloop( dspace, 'gdd' );

% show proxy decision space and fitted GDD function
plotdspace( dspace, param );
